@@ -56,6 +56,10 @@
 #'   indicating the proportion of respondents to be allocated to the EBMA fold.
 #'   Default is \eqn{1/3}. \emph{Note:} ignored if \code{folds} is provided, but
 #'   must be specified otherwise.
+#' @param stacking Model averaging via stacking. Stacking is an alternative to
+#'   EBMA. Default is \code{FALSE}. If set to TRUE a model ensemble is generated
+#'   via stacking. \code{ebma.size} must be set to 0 if stacking is \code{TRUE}.
+#'   Stacking is faster than EBMA.
 #' @param cores The number of cores to be used. An integer indicating the number
 #'   of processor cores used for parallel computing. Default is 1.
 #' @param k.folds Number of cross-validation folds. An integer-valued scalar
@@ -236,7 +240,7 @@
 #'   survey = taxes_survey,
 #'   census = taxes_census,
 #'   ebma.size = 0,
-#'   cores = max_cores,
+#'   cores = 2,
 #'   best.subset = FALSE,
 #'   lasso = FALSE,
 #'   pca = FALSE,
@@ -286,7 +290,7 @@
 #'   census = taxes_census,
 #'   gb.L2.reg = TRUE,
 #'   svm.L2.reg = TRUE,
-#'   cores = max_cores
+#'   cores = min(2, max_cores)
 #'   )
 #' }
 #' @export
@@ -300,7 +304,8 @@
 
 auto_MrP <- function(y, L1.x, L2.x, L2.unit, L2.reg = NULL, L2.x.scale = TRUE, pcs = NULL,
                      folds = NULL, bin.proportion = NULL, bin.size = NULL, survey, census,
-                     ebma.size = 1/3, cores = 1, k.folds = 5, cv.sampling = "L2 units",
+                     ebma.size = 1/3, stacking = FALSE, cores = 1, k.folds = 5,
+                     cv.sampling = "L2 units",
                      loss.unit = c("individuals", "L2 units"),
                      loss.fun = c("msfe", "cross-entropy", "f1", "MSE"),
                      best.subset = TRUE, lasso = TRUE, pca = TRUE, gb = TRUE, svm = TRUE,
