@@ -1434,6 +1434,7 @@ multicore <- function(cores = 1, type, cl = NULL) {
     if( Sys.info()["sysname"] == "Windows" ){
       cl <- parallel::makeCluster(cores)
       doParallel::registerDoParallel(cl)
+      parallel::clusterCall(cl, function(x) .libPaths(x), .libPaths())
     } else {
       cl <- parallel::makeForkCluster(cores)
       doParallel::registerDoParallel(cl)
@@ -1520,6 +1521,8 @@ predict_glmmLasso <- function(census, m, L1.x, lasso.L2.x, L2.unit, L2.reg) {
 #'   \code{0.95}. Confidence intervals are based on bootstrapped estimates and
 #'   will not be printed if bootstrapping was not carried out.
 #' @param ... Additional arguments affecting the summary produced.
+#' @return Returns a \code{ggplot2} object of the preference estimates for the
+#' selected classifier.
 #' @export
 #' @export plot.autoMrP
 
@@ -1607,6 +1610,8 @@ plot.autoMrP <- function(x, algorithm = "ebma", ci.lvl = 0.95, ...){
 #' @param n Number of rows to be printed. An integer scalar. Default is
 #'   \code{10}.
 #' @param ... Additional arguments affecting the summary produced.
+#' @return No return value, prints a summary of the context level preference
+#'  estimates to the console.
 #' @export
 #' @export summary.autoMrP
 
